/// <reference types="react" />
export declare enum FileType {
    PDF = "pdf"
}
export declare enum BlockType {
    PAGE = "PAGE",
    LINE = "LINE",
    WORD = "WORD",
    TABLE = "TABLE",
    CELL = "CELL",
    SELECTION_ELEMENT = "SELECTION_ELEMENT"
}
export declare type OCRBlock = {
    BlockType: BlockType;
    Geometry: {
        BoundingBox: {
            Width: number;
            Height: number;
            Left: number;
            Top: number;
        };
        Polygon: Array<{
            X: number;
            Y: number;
        }>;
    };
    Id: string;
    Relationships: Array<{
        Type: string;
        Ids: string[];
    }>;
    Page: number;
    Confidence: number;
    Text: string;
};
export declare type OcrData = {
    Blocks: OCRBlock[];
    DocumentMetadata: {
        Pages: number;
    };
};
export declare type OCRBlockRenderProps = OCRBlock & {
    width: number;
    height: number;
};
export declare type OCRPageRenderProps = {
    page: number;
    blocks?: OCRBlock[];
    children: React.ReactNode;
};
export declare type OCROverlayRendererProps = {
    blocks: OCRBlock[];
    customTextRenderComponent?: (props: OCRBlockRenderProps) => JSX.Element;
    width: number;
    height: number;
};
