function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var reactPdf = require('react-pdf');

(function (FileType) {
  FileType["PDF"] = "pdf";
})(exports.FileType || (exports.FileType = {}));
(function (BlockType) {
  BlockType["PAGE"] = "PAGE";
  BlockType["LINE"] = "LINE";
  BlockType["WORD"] = "WORD";
  BlockType["TABLE"] = "TABLE";
  BlockType["CELL"] = "CELL";
  BlockType["SELECTION_ELEMENT"] = "SELECTION_ELEMENT";
})(exports.BlockType || (exports.BlockType = {}));

var DefaultPageRender = function DefaultPageRender(props) {
  return React__default.createElement(React.Fragment, null, props.children);
};

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;
  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }
  return target;
}

var styles = {"defaultRenderText":"_3Q0a-"};

var _excluded = ["width", "height"];
var DefaultTextRenderer = function DefaultTextRenderer(_ref) {
  var width = _ref.width,
    height = _ref.height,
    block = _objectWithoutPropertiesLoose(_ref, _excluded);
  var defaultHeight = block.Geometry.BoundingBox.Height * height;
  return React__default.createElement("div", {
    key: block.Id,
    className: styles.defaultRenderText,
    style: {
      width: block.Geometry.BoundingBox.Width * width + "px",
      height: defaultHeight + "px",
      fontSize: "calc(" + defaultHeight + "px * 0.8)"
    }
  }, block.Text);
};

var styles$1 = {"overlayContent":"_1gKhP"};

var OCROverlayRenderer = function OCROverlayRenderer(_ref) {
  var blocks = _ref.blocks,
    width = _ref.width,
    height = _ref.height,
    customTextRenderComponent = _ref.customTextRenderComponent;
  var RenderText = customTextRenderComponent !== null && customTextRenderComponent !== void 0 ? customTextRenderComponent : DefaultTextRenderer;
  return React__default.createElement("div", {
    className: styles$1.overlayContent
  }, React__default.createElement("div", {
    className: styles$1.ocrPage
  }, blocks === null || blocks === void 0 ? void 0 : blocks.map(function (block) {
    return React__default.createElement("div", {
      key: block.Id,
      style: {
        left: block.Geometry.BoundingBox.Left * width + "px",
        top: block.Geometry.BoundingBox.Top * height + "px",
        position: 'absolute'
      }
    }, React__default.createElement(RenderText, Object.assign({}, block, {
      width: width,
      height: height
    })));
  })));
};

var styles$2 = {"pageContainer":"_2S3gd","ocrBlock":"_23n6h","ocrPage":"_3IMu9"};

reactPdf.pdfjs.GlobalWorkerOptions.workerSrc = "//unpkg.com/pdfjs-dist@" + reactPdf.pdfjs.version + "/build/pdf.worker.min.js";
var OCRPdfRenderer = function OCRPdfRenderer(_ref) {
  var file = _ref.file,
    _ref$ocrData = _ref.ocrData,
    ocrData = _ref$ocrData === void 0 ? [] : _ref$ocrData,
    customTextRenderComponent = _ref.customTextRenderComponent,
    customPageRenderComponent = _ref.customPageRenderComponent,
    _ref$size = _ref.size,
    size = _ref$size === void 0 ? {
      width: 500
    } : _ref$size,
    _ref$showOnlyResultPa = _ref.showOnlyResultPages,
    showOnlyResultPages = _ref$showOnlyResultPa === void 0 ? false : _ref$showOnlyResultPa;
  var _useState = React.useState([]),
    pages = _useState[0],
    setPages = _useState[1];
  var _useState2 = React.useState({
      width: size.width,
      height: 0
    }),
    _useState2$ = _useState2[0],
    width = _useState2$.width,
    height = _useState2$.height,
    setPageSize = _useState2[1];
  var handlePageLoad = React.useCallback(function () {
    try {
      if (!file) {
        return Promise.resolve();
      }
      return Promise.resolve(reactPdf.pdfjs.getDocument(file).promise).then(function (docData) {
        var pageCount = docData._pdfInfo.numPages;
        var pagePromises = Array.from({
          length: pageCount
        }, function (_, pageNumber) {
          return docData.getPage(pageNumber + 1).then(function (pageData) {
            return pageData.getTextContent().then(function (textContent) {
              return textContent.items.map(function (v) {
                return v.str;
              }).join(' ');
            });
          });
        });
        return Promise.all(pagePromises).then(function (p) {
          setPages(p);
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }, [file]);
  React.useEffect(function () {
    handlePageLoad();
  }, [file, handlePageLoad]);
  var RenderPage = customPageRenderComponent !== null && customPageRenderComponent !== void 0 ? customPageRenderComponent : DefaultPageRender;
  var rootList = Object.keys(showOnlyResultPages ? ocrData : pages);
  return React__default.createElement(reactPdf.Document, {
    file: file,
    onLoadSuccess: function onLoadSuccess(p) {
      p.getPage(1).then(function (page) {
        setPageSize({
          width: width || size.width,
          height: width * (page.view[3] / page.view[2])
        });
      });
    }
  }, rootList.map(function (pString) {
    var _ocrData$i, _ocrData$i2;
    var i = parseInt(pString, 10);
    return React__default.createElement("div", {
      key: Math.random().toString(36).substring(7),
      className: styles$2.pageContainer,
      style: {
        width: width
      }
    }, React__default.createElement(RenderPage, {
      page: i,
      blocks: (_ocrData$i = ocrData[i]) !== null && _ocrData$i !== void 0 ? _ocrData$i : []
    }, React__default.createElement(reactPdf.Page, {
      renderTextLayer: false,
      width: width,
      pageNumber: i,
      renderAnnotationLayer: false
    }), React__default.createElement(OCROverlayRenderer, {
      blocks: (_ocrData$i2 = ocrData[i]) !== null && _ocrData$i2 !== void 0 ? _ocrData$i2 : [],
      width: width,
      height: height,
      customTextRenderComponent: customTextRenderComponent
    })));
  }));
};

var groupPages = function groupPages(blocks) {
  var pages = {};
  blocks.forEach(function (block) {
    pages[block.Page] = pages[block.Page] || [];
    pages[block.Page].push(block);
  });
  return pages;
};
var ReactOCRRenderer = function ReactOCRRenderer(_ref) {
  var file = _ref.file,
    type = _ref.type,
    ocrData = _ref.ocrData,
    _ref$searchText = _ref.searchText,
    searchText = _ref$searchText === void 0 ? [] : _ref$searchText,
    _ref$highlightedBlock = _ref.highlightedBlockTypes,
    highlightedBlockTypes = _ref$highlightedBlock === void 0 ? [exports.BlockType.WORD] : _ref$highlightedBlock,
    customTextRenderComponent = _ref.customTextRenderComponent,
    customPageRenderComponent = _ref.customPageRenderComponent,
    size = _ref.size,
    showOnlyResultPages = _ref.showOnlyResultPages;
  var cleanedSearchText = React.useMemo(function () {
    return typeof searchText === 'string' ? searchText.toLowerCase() : searchText.map(function (el) {
      return el.toLowerCase();
    });
  }, [searchText]);
  var filteredBlocks = React.useMemo(function () {
    return ocrData.Blocks.filter(function (block) {
      if (!highlightedBlockTypes.includes(block.BlockType)) {
        return false;
      }
      var textCheck = typeof cleanedSearchText === 'string' ? !block.Text.toLowerCase().includes(cleanedSearchText) : !cleanedSearchText.some(function (el) {
        return !block.Text ? false : block.Text.toLowerCase().includes(el);
      });
      if (cleanedSearchText.length && textCheck) {
        return false;
      }
      return true;
    });
  }, [ocrData, cleanedSearchText, highlightedBlockTypes]);
  var pageGroups = React.useMemo(function () {
    return groupPages(filteredBlocks);
  }, [filteredBlocks]);
  if (!Object.keys(pageGroups).length) {
    return React__default.createElement("div", null, "No data found");
  }
  if (type === exports.FileType.PDF) {
    return React__default.createElement(OCRPdfRenderer, {
      file: file,
      ocrData: pageGroups,
      customTextRenderComponent: customTextRenderComponent,
      customPageRenderComponent: customPageRenderComponent,
      size: size,
      showOnlyResultPages: showOnlyResultPages
    });
  }
  return React__default.createElement("div", null, file);
};

exports.default = ReactOCRRenderer;
//# sourceMappingURL=index.js.map
